@@ -1,7 +1,9 @@
 import json
+import sys
 import jsonlines
 import time
 import os
+import yaml
 
 from typing import List, Any
 
@@ -70,12 +72,15 @@ def appendline(line: str, f: str):
     with open(f, "a") as fh:
         fh.write(line.strip() + "\n")
 
+def eprint(*args, **kwargs):
+    print(*args, file=sys.stderr, **kwargs)
+
 def getenv(k, default=None):
     v = os.getenv(k)
     if v is None and default is not None:
         v = default
     assert v
-    print("%s=%s" % (k, v))
+    eprint("%s=%s" % (k, v))
     return v
 
 def log_progress(l: List[Any], desc=None, print_item=False):
@@ -86,5 +91,13 @@ def log_progress(l: List[Any], desc=None, print_item=False):
             info += " " + desc
         if print_item:
             info += " " + str(item)
-        print(f"Progress: item {i}" + info)
-        yield item
\ No newline at end of file
+        print(f"Progress: {i}/{total}" + info, flush=True)
+        yield item
+
+def load_yaml(path: str):
+    with open(path, 'r') as f:
+        return yaml.safe_load(f)
+
+def write_yaml(stuff, path: str):
+    with open(path, 'w') as f:
+        yaml.safe_dump(stuff, f, default_flow_style=False, sort_keys=False)
\ No newline at end of file
